@@ -26,9 +26,6 @@
 #include <math.h>
 
 #include <hb.h>
-#ifdef HAVE_FREETYPE
-#include <hb-ft.h>
-#endif
 
 typedef struct draw_data_t
 {
@@ -1074,9 +1071,10 @@ test_hb_draw_immutable (void)
   hb_draw_funcs_destroy (draw_funcs);
 }
 
-#ifdef HAVE_FREETYPE
-static void test_hb_draw_ft (void)
+static void
+test_hb_draw_funcs (const void* user_data)
 {
+  const char *font_funcs_name = user_data;
   char str[1024];
   draw_data_t draw_data = {
     .str = str,
@@ -1085,7 +1083,8 @@ static void test_hb_draw_ft (void)
   {
     hb_face_t *face = hb_test_open_font_file ("fonts/glyphs.ttf");
     hb_font_t *font = hb_font_create (face);
-    hb_ft_font_set_funcs (font);
+    hb_bool_t ret = hb_font_set_funcs_using (font, font_funcs_name);
+    g_assert (ret);
     hb_face_destroy (face);
     {
       draw_data.consumed = 0;
@@ -1093,18 +1092,13 @@ static void test_hb_draw_ft (void)
       char expected[] = "M50,0L50,750L450,750L450,0L50,0Z";
       g_assert_cmpmem (str, draw_data.consumed, expected, sizeof (expected) - 1);
     }
-    {
-      draw_data.consumed = 0;
-      hb_font_draw_glyph (font, 5, funcs, &draw_data);
-      char expected[] = "M15,0Q15,0 15,0Z";
-      g_assert_cmpmem (str, draw_data.consumed, expected, sizeof (expected) - 1);
-    }
     hb_font_destroy (font);
   }
   {
     hb_face_t *face = hb_test_open_font_file ("fonts/cff1_flex.otf");
     hb_font_t *font = hb_font_create (face);
-    hb_ft_font_set_funcs (font);
+    hb_bool_t ret = hb_font_set_funcs_using (font, font_funcs_name);
+    g_assert (ret);
     hb_face_destroy (face);
 
     draw_data.consumed = 0;
@@ -1122,8 +1116,9 @@ static void test_hb_draw_ft (void)
 }
 
 static void
-test_hb_draw_compare_ot_ft (void)
+test_hb_draw_compare_ot_funcs (const void *user_data)
 {
+  const char* font_funcs_name = user_data;
   char str[1024];
   draw_data_t draw_data = {
     .str = str,
@@ -1145,7 +1140,8 @@ test_hb_draw_compare_ot_ft (void)
   hb_font_draw_glyph (font, 1, funcs, &draw_data);
   draw_data.str[draw_data.consumed] = '\0';
 
-  hb_ft_font_set_funcs (font);
+  hb_bool_t ret = hb_font_set_funcs_using (font, font_funcs_name);
+  g_assert (ret);
 
   hb_font_draw_glyph (font, 1, funcs, &draw_data2);
   draw_data2.str[draw_data2.consumed] = '\0';
@@ -1155,7 +1151,6 @@ test_hb_draw_compare_ot_ft (void)
   hb_font_destroy (font);
   hb_face_destroy (face);
 }
-#endif
 
 int
 main (int argc, char **argv)
@@ -1191,10 +1186,14 @@ main (int argc, char **argv)
   hb_test_add (test_hb_draw_synthetic_slant);
   hb_test_add (test_hb_draw_subfont_scale);
   hb_test_add (test_hb_draw_immutable);
-#ifdef HAVE_FREETYPE
-  hb_test_add (test_hb_draw_ft);
-  hb_test_add (test_hb_draw_compare_ot_ft);
-#endif
+
+  const char **font_funcs = hb_font_list_funcs ();
+  for (const char **font_funcs_name = font_funcs; *font_funcs_name; font_funcs_name++)
+  {
+    hb_test_add_flavor (*font_funcs_name, test_hb_draw_funcs);
+    hb_test_add_flavor (*font_funcs_name, test_hb_draw_compare_ot_funcs);
+  }
+
   unsigned result = hb_test_run ();
 
   hb_draw_funcs_destroy (funcs);
